@@ -1,2 +1,2 @@
 from .sankey_chart import getSankey,transform_data_for_sankey
-from .heatmap import heatmap
\ No newline at end of file
+from .heatmap import heatmap, correlation_heatmap
\ No newline at end of file
